@@ -80,25 +80,39 @@ sub run ($self) {
     # create zipped par
     my $zip = Archive::Zip->new;
 
-    $zip->addTree(
-        {   root             => $temp->path,
-            zipName          => q[],
-            compressionLevel => 9,
+    for my $file ( values $self->tree->{files}->%* ) {
+        my $member;
+
+        if ( ref $file->{content} ) {
+            $member = $zip->addString(
+                {   string           => $file->{content},
+                    zipName          => $file->{path},
+                    compressionLevel => 9,
+                }
+            );
+        }
+        else {
+            $member = $zip->addFile(
+                {   filename         => $file->{source_path},
+                    zipName          => $file->{path},
+                    compressionLevel => 9,
+                }
+            );
         }
-    );
 
-    my $zip_fh = P->file->tempfile( suffix => 'zip' );
+        $member->unixFileAttributes( oct 666 );
+    }
 
-    $zip->writeToFileHandle($zip_fh);
+    my $zip_path = P->file->temppath( suffix => 'zip' );
 
-    $zip_fh->close;
+    $zip->writeToFileNamed("$zip_path");
 
     # create parl executable
     my $parl_path = P->file->temppath( suffix => $self->par_suffix );
 
     print 'writing parl ... ';
 
-    my $cmd = qq[parl -B -O$parl_path ] . $zip_fh->path;
+    my $cmd = qq[parl -B -O"$parl_path" "$zip_path"];
 
     `$cmd` or die;
 
@@ -168,15 +182,13 @@ sub _add_modules ($self) {
 sub _add_shlib ($self) {
     die q[Currently on MSWIN platform is supported] if !$MSWIN;
 
-    my $dso;
-
     state $system_root = P->path( $ENV{SYSTEMROOT}, is_dir => 1 )->realpath;
 
     state $is_system_lib = sub ($path) {
         return $path =~ m[^\Q$system_root\E]smi ? 1 : 0;
     };
 
-    my $find_dso = sub ( $so_path ) {
+    my $find_dso = sub ( $dso, $so_path ) {
         my $out = `objdump -ax $so_path`;
 
         while ( $out =~ /^\s*DLL Name:\s*(\S+)/smg ) {
@@ -190,7 +202,7 @@ sub _add_shlib ($self) {
 
                 $dso->{$so} = $path->to_string;
 
-                __SUB__->( $path->to_string );
+                __SUB__->( $dso, $path->to_string );
             }
 
             # so wasn't found in $PATH
@@ -217,24 +229,28 @@ sub _add_shlib ($self) {
     };
 
     # scan deps for perl executalbe and modules shared objects
+    my $dso = {};
+
     for my $path ( $^X, values $self->{shared_objects}->%* ) {
-        $find_dso->($path);
+        $find_dso->( $dso, $path );
     }
 
+    # do not add perl deps, because they are already packed to parl
+    $find_dso->( my $perl_dso = {}, $^X );
+
+    delete $dso->@{ keys $perl_dso->%* };
+
+    my $perl_path = P->path($^X);
+
+    $dso->{ $perl_path->filename } = "$perl_path";
+
     # add found deps
-    for my $filename ( keys $dso->%* ) {
+    for my $filename ( sort keys $dso->%* ) {
         $self->tree->add_file( "shlib/$Config{archname}/$filename", $dso->{$filename} );
 
-        say qq[shlib added: "$filename"];
+        say sprintf 'shlib added: %-30s %s', $filename, $dso->{$filename};
     }
 
-    # add perl executable
-    my $perl_filename = P->path($^X)->filename;
-
-    $self->tree->add_file( "shlib/$Config{archname}/$perl_filename", $^X );
-
-    say qq[shlib added: "$perl_filename"];
-
     return;
 }
 
@@ -348,7 +364,7 @@ sub _add_dist ( $self, $dist ) {
     if ( $dist->name eq $self->dist->name ) {
 
         # add main dist share
-        $self->tree->add_dir( $dist->share_dir, '/share/' );
+        $self->tree->add_dir( $dist->share_dir, 'share/' );
 
         # add main dist dist-id.json
         $self->tree->add_file( 'share/dist-id.json', P->data->to_json( $dist->id, readable => 1 ) );
@@ -511,13 +527,13 @@ sub _error ( $self, $msg ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 291                  | Subroutines::ProhibitManyArgs - Too many arguments                                                             |
+## |    3 | 307                  | Subroutines::ProhibitManyArgs - Too many arguments                                                             |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    3 | 381                  | RegularExpressions::ProhibitCaptureWithoutTest - Capture variable used outside conditional                     |
+## |    3 | 397                  | RegularExpressions::ProhibitCaptureWithoutTest - Capture variable used outside conditional                     |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    2 | 466, 469             | ValuesAndExpressions::ProhibitEscapedCharacters - Numeric escapes in interpolated string                       |
+## |    2 | 482, 485             | ValuesAndExpressions::ProhibitEscapedCharacters - Numeric escapes in interpolated string                       |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    1 | 398, 404             | CodeLayout::ProhibitParensWithBuiltins - Builtin function called with parentheses                              |
+## |    1 | 414, 420             | CodeLayout::ProhibitParensWithBuiltins - Builtin function called with parentheses                              |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
